##########################################################################
##########################################################################
##########################################################################
### Mantel test between two distance matrices. 
  #order of the samples must be the same for both OTU tables!
  #Inputs are OTU tables (SAMPLES as COLUMNS!)

library(vegan)

input_table1 = read.table("Nova_table.txt", sep="\t", header=T, row.names=1)
input_table2 = read.table("DNB_table.txt", sep="\t", header=T, row.names=1)

#Hellinger transformation
input_table1 = t(input_table1)
input_table1.hell = decostand(input_table1, "hellinger")
input_table2 = t(input_table2)
input_table2.hell = decostand(input_table2, "hellinger")  

#Bray-Curtis matrix
input_table1.hell.dist = vegdist(input_table1.hell, "bray", permutations = 9999)
input_table2.hell.dist = vegdist(input_table2.hell, "bray", permutations = 9999)

#MANTEL TEST between input_table1 and input_table2
manteltest = mantel(input_table1.hell.dist, input_table2.hell.dist, method="spear", permutations = 9999)
manteltest

#PLOT Mantel correlations
ylabname = "DNBSEQ" #Y bar name as input_table2 filename
xlabname = "NovaSeq"

par(pty="s") #plot as a square
plot(input_table1.hell.dist, input_table2.hell.dist, pch=15, col="black", xlim=c(0.05, 0.979), ylim=c(0.05, 0.979),
     xlab = xlabname, ylab = ylabname)

#Save plot as PDF
dev.copy2pdf(out.type = "pdf")
dev.off()
pdf_filename = paste(xlabname, ylabname, sep = " vs ")
pdf_filename = paste(pdf_filename, "pdf", sep = ".")
file.rename(from = "Rplot.pdf", to = pdf_filename)


##########################################################################
##########################################################################
##########################################################################
### Procrustes test 

#NMDS for Procustres
  #(input tables from above)
metaMDS_input_table1 = metaMDS(input_table1.hell.dist)
metaMDS_input_table2 = metaMDS(input_table2.hell.dist)

#Procrusts analyses
procrust = protest(metaMDS_input_table1, metaMDS_input_table2, permutations = 9999, symmetric = TRUE)
procrust

#Plot
plot(procrust, pch=21, kind = 2, symmetric = TRUE)
plot(procrust, cex = 1, pch = 21)
#display sample names on plot
text(procrust, label=row.names(input_table1),cex = 0.5, pos = 3, col = "red")

##########################################################################
##########################################################################
##########################################################################
#Rarefy to even depth
library('base')
library('phyloseq')

#import OTU table (matrix#3) containing DNBSEQ and NovaSeq data
otumat = as.matrix(as.data.frame(read.table("Full_matrix3",header=TRUE, row.names=1)))

################
#Convert imported data to phyloseq items
OTU = otu_table(otumat, taxa_are_rows = TRUE)
physeq = phyloseq(OTU)

#rarefy
raref_tab = rarefy_even_depth(physeq, sample.size = min(sample_sums(physeq)),
                               rngseed = TRUE, replace = TRUE, trimOTUs = TRUE, verbose = TRUE)

#export raref OTU table
OTU1 = as(otu_table(raref_tab), "matrix")
OTU_raref = as.data.frame(OTU1)
write.table(OTU_raref, file = "rarefied_matrix.txt")


